CharacteristicValueSpecification

Struct CharacteristicValueSpecification 

pub struct CharacteristicValueSpecification {
    pub base_type: Option<String>,
    pub schema_location: Option<String>,
    pub type_: Option<String>,
    pub is_default: Option<bool>,
    pub range_interval: Option<String>,
    pub regex: Option<String>,
    pub unit_of_measure: Option<String>,
    pub valid_for: Option<TimePeriod>,
    pub value: Option<Any>,
    pub value_from: Option<i64>,
    pub value_to: Option<i64>,
    pub value_type: Option<String>,
}
specification of a value (number or text or an object) that can be assigned to a Characteristic.

Fields

base_type: Option<String>

When sub-classing, this defines the super-class

schema_location: Option<String>

A URI to a JSON-Schema file that defines additional attributes and relationships

type_: Option<String>

When sub-classing, this defines the sub-class Extensible name

is_default: Option<bool>

If true, the Boolean Indicates if the value is the default value for a characteristic

range_interval: Option<String>

An indicator that specifies the inclusion or exclusion of the valueFrom and valueTo attributes. If applicable, possible values are “open”, “closed”, “closedBottom” and “closedTop”.

regex: Option<String>

A regular expression constraint for given value

unit_of_measure: Option<String>

A length, surface, volume, dry measure, liquid measure, money, weight, time, and the like. In general, a determinate quantity or magnitude of the kind designated, taken as a standard of comparison for others of the same kind, in assigning to them numerical values, as 1 foot, 1 yard, 1 mile, 1 square foot.

valid_for: Option<TimePeriod>

A period of time, either as a deadline (endDateTime only) a startDateTime only, or both

value: Option<Any>

The value that a characteristic can take on

value_from: Option<i64>

The low range value that a characteristic can take on

value_to: Option<i64>

The upper range value that a characteristic can take on

value_type: Option<String>

A kind of value that the characteristic value can take on, such as numeric, text and so forth