pub struct UsageCreateEventPayload {
pub usage: Option<Usage>,
}Expand description
The event data structure
Fields
usage: Option<Usage>An occurrence of employing a Product, Service, or Resource for its intended purpose, which is of interest to the business and can have charges applied to it. It is comprised of characteristics, which represent attributes of usage.