pub struct Characteristic {
pub base_type: Option<String>,
pub schema_location: Option<String>,
pub type_: Option<String>,
pub characteristic_relationship: Option<Vec<CharacteristicRelationship>>,
pub id: Option<String>,
pub name: String,
pub value: Any,
pub value_type: Option<String>,
}Expand description
Describes a given characteristic of an object or entity through a name/value pair.
Fields
base_type: Option<String>When sub-classing, this defines the super-class
schema_location: Option<String>A URI to a JSON-Schema file that defines additional attributes and relationships
type_: Option<String>When sub-classing, this defines the sub-class Extensible name
characteristic_relationship: Option<Vec<CharacteristicRelationship>>A list of characteristics relationships related to this characteristic.
id: Option<String>Unique identifier of the characteristic
name: StringName of the characteristic
value: AnyValue of the characteristic
value_type: Option<String>Data type of the value of the characteristic