pub struct ManagedPolicyOperatorMvo {
pub policy_managed_entity_mvo: PolicyManagedEntityMvo,
pub policy_operator_mvo: PolicyOperatorMvo,
}Expand description
Managed PolicyOperator
Fields
policy_managed_entity_mvo: PolicyManagedEntityMvoInlined fields from PolicyManagedEntityMvo
policy_operator_mvo: PolicyOperatorMvoA PolicyOperator is an entity that defines the logical operations that can be used to combine multiple PolicyConditions within a PolicyExpression.