pub struct AlternateServiceProposal {
pub base_type: Option<String>,
pub schema_location: Option<String>,
pub type_: Option<String>,
pub alternate_service: Option<ServiceRefOrValue>,
pub alternate_service_availability_date: Option<DateTime>,
pub href: Option<String>,
pub id: Option<String>,
}Expand description
Alternate service proposal is used when the requested service is not available with characteristic and date asked for. An alternate proposal could be a distinct serviceSpecification close to requested one or same as requested but with a different activation date
Fields
base_type: Option<String>When sub-classing, this defines the super-class
schema_location: Option<String>A URI to a JSON-Schema file that defines additional attributes and relationships
type_: Option<String>When sub-classing, this defines the sub-class Extensible name
alternate_service: Option<ServiceRefOrValue>A Service to be created defined by value or existing defined by reference. The polymorphic attributes @type, @schemaLocation & @referredType are related to the Service entity and not the RelatedServiceRefOrValue class itself
alternate_service_availability_date: Option<DateTime>Alternate availability date in case seller is not able to meet requested expected availability date for the service
href: Option<String>Hyperlink reference
id: Option<String>Identifier of a alternate service proposal