pub struct AttachmentRefOrValue {Show 14 fields
pub base_type: Option<String>,
pub referred_type: Option<String>,
pub schema_location: Option<String>,
pub type_: Option<String>,
pub attachment_type: Option<String>,
pub content: Option<String>,
pub description: Option<String>,
pub href: Option<String>,
pub id: Option<String>,
pub mime_type: Option<String>,
pub name: Option<String>,
pub size: Option<Quantity>,
pub url: Option<String>,
pub valid_for: Option<TimePeriod>,
}Expand description
An attachment by value or by reference. An attachment complements the description of an element, for example through a document, a video, a picture.
Fields
base_type: Option<String>When sub-classing, this defines the super-class
referred_type: Option<String>The actual type of the target instance when needed for disambiguation.
schema_location: Option<String>A URI to a JSON-Schema file that defines additional attributes and relationships
type_: Option<String>When sub-classing, this defines the sub-class Extensible name
attachment_type: Option<String>Attachment type such as video, picture
content: Option<String>The actual contents of the attachment object, if embedded, encoded as base64
description: Option<String>A narrative text describing the content of the attachment
href: Option<String>URI for this Attachment
id: Option<String>Unique identifier for this particular attachment
mime_type: Option<String>Attachment mime type such as extension file for video, picture and document
name: Option<String>The name of the attachment
size: Option<Quantity>An amount in a given unit
url: Option<String>Uniform Resource Locator, is a web page address (a subset of URI)
valid_for: Option<TimePeriod>A period of time, either as a deadline (endDateTime only) a startDateTime only, or both