pub struct CharacteristicSpecificationRelationship {
pub base_type: Option<String>,
pub schema_location: Option<String>,
pub type_: Option<String>,
pub characteristic_specification_id: Option<String>,
pub name: Option<String>,
pub parent_specification_href: Option<String>,
pub parent_specification_id: Option<String>,
pub relationship_type: Option<String>,
pub valid_for: Option<TimePeriod>,
}Expand description
An aggregation, migration, substitution, dependency or exclusivity relationship between/among Characteristic specifications. The specification characteristic is embedded within the specification whose ID and href are in this entity, and identified by its ID.
Fields
base_type: Option<String>When sub-classing, this defines the super-class
schema_location: Option<String>A URI to a JSON-Schema file that defines additional attributes and relationships
type_: Option<String>When sub-classing, this defines the sub-class Extensible name
characteristic_specification_id: Option<String>Unique identifier of the characteristic within the specification
name: Option<String>Name of the target characteristic within the specification
parent_specification_href: Option<String>Hyperlink reference to the parent specification containing the target characteristic
parent_specification_id: Option<String>Unique identifier of the parent specification containing the target characteristic
relationship_type: Option<String>Type of relationship such as aggregation, migration, substitution, dependency, exclusivity
valid_for: Option<TimePeriod>A period of time, either as a deadline (endDateTime only) a startDateTime only, or both