pub struct CheckServiceQualificationStateChangeEventPayload {
pub check_service_qualification: Option<CheckServiceQualification>,
}Expand description
The event data structure
Fields
check_service_qualification: Option<CheckServiceQualification>CheckServiceQualification is used to perform a technical eligibility on service configuration(s). It allows to retrieve services that are technically available in the context of the interaction (place, party, service characteristics, …).