pub struct ImpactPattern {
pub base_type: Option<String>,
pub schema_location: Option<String>,
pub type_: Option<String>,
pub characteristic: Option<Vec<Characteristic>>,
pub description: Option<String>,
pub href: Option<String>,
pub id: Option<String>,
}Expand description
Define the patterns of impact (optional), such as other service characteristics- Used when defining impact through another pattern than the pre-defined attributes
Fields
base_type: Option<String>When sub-classing, this defines the super-class
schema_location: Option<String>A URI to a JSON-Schema file that defines additional attributes and relationships
type_: Option<String>When sub-classing, this defines the sub-class Extensible name
characteristic: Option<Vec<Characteristic>>A generic list of any type of elements. Used for extensions or loose element encapsulation from other namespaces
description: Option<String>Basic description of the impact pattern
href: Option<String>Hyperlink reference
id: Option<String>unique identifier