MeasureThresholdRuleViolation

Struct MeasureThresholdRuleViolation 

pub struct MeasureThresholdRuleViolation {
Show 15 fields pub base_type: Option<String>, pub schema_location: Option<String>, pub type_: Option<String>, pub applied_consequence: Option<Vec<AppliedConsequence>>, pub conformance_comparator_exact: Option<bool>, pub conformance_comparator_lower: Option<String>, pub conformance_comparator_upper: Option<String>, pub conformance_target_exact: Option<String>, pub conformance_target_lower: Option<String>, pub conformance_target_upper: Option<String>, pub description: Option<String>, pub name: Option<String>, pub number_of_allowed_crossing: Option<i64>, pub threshold_rule_severity: Option<String>, pub tolerance_period: Option<Duration>,
}
A measureThresholdRuleViolation is a violation of a rule that defines the in the MericDefMeasureThresholdRule.

Fields

base_type: Option<String>

When sub-classing, this defines the super-class

schema_location: Option<String>

A URI to a JSON-Schema file that defines additional attributes and relationships

type_: Option<String>

When sub-classing, this defines the sub-class Extensible name

applied_consequence: Option<Vec<AppliedConsequence>>

An Applied Consequence defines the action (prescribed action or notification) to take when a MeasureThresholdRuleViolation occurs.

conformance_comparator_exact: Option<bool>

An operator that when applied on a value specifies whether it is the same target value or not. This operator is used to compare with the conformanceTargetExact if used.

conformance_comparator_lower: Option<String>

An operator that when applied on a value specifies whether a threshold is crossed or ceased to be crossed. This operator is used to compare with the conformanceTargetLower if used.

conformance_comparator_upper: Option<String>

An operator that when applied on a value specifies whether a threshold is crossed or ceased to be crossed. This operator is used to compare with the conformanceTargetUpper if used.

conformance_target_exact: Option<String>

To cater for values that are not numerical test metrics (e.g. a DSL line can be Synchronised or Unsynchronised. If the latter, the test should result in a rule violation).The allowed value can contain a REGEX expression.

conformance_target_lower: Option<String>

A value used to determine if the threshold is crossed or ceases to be crossed. It represents the lower limit. The value should be less than the conformanceTargetUpper if used. The conformance comparators should also be logically defined so as to not lead to a logically impossible condition.

conformance_target_upper: Option<String>

A value used to determine if the threshold is crossed or ceases to be crossed. It represents the Upper limit. The value should be greater than the conformanceTargetLower if used. The conformance comparators should also be logically defined so as to not lead to a logically impossible condition.

description: Option<String>

Description for the MetricDefMeasureThresholdRule .

name: Option<String>

Name for the MetricDefMeasureThresholdRule .

number_of_allowed_crossing: Option<i64>

The number of allowed crossing occurrences in reference to the tolerancePeriod without a consequence being initiated.

threshold_rule_severity: Option<String>

A threshold can be generated in different severity levels. A crossing for each level may require a different condition and possibly trigger a different consequence.

tolerance_period: Option<Duration>

A time interval in a given unit of time