pub struct QueryServiceQualificationDeleteEventPayload {
pub query_service_qualification: Option<QueryServiceQualification>,
}Expand description
The event data structure
Fields
query_service_qualification: Option<QueryServiceQualification>QueryServiceQualification is used to retrieve a list of services that are technically available in the context of the interaction (place, party, service characteristics, …).