pub struct ResourceAlarmRef {
pub base_type: Option<String>,
pub referred_type: Option<String>,
pub schema_location: Option<String>,
pub type_: Option<String>,
pub change_request: Option<EntityRef>,
pub href: Option<String>,
pub id: String,
}Expand description
A set of alarm ids identifying the alarms that are underlying this problem.
Fields
base_type: Option<String>When sub-classing, this defines the super-class
referred_type: Option<String>The actual type of the target instance when needed for disambiguation.
schema_location: Option<String>A URI to a JSON-Schema file that defines additional attributes and relationships
type_: Option<String>When sub-classing, this defines the sub-class Extensible name
change_request: Option<EntityRef>Entity reference schema to be use for all entityRef class.
href: Option<String>Reference of the Alarm
id: StringUnique identifier of the Alarm