pub struct ServiceCategoryCreate {Show 13 fields
pub base_type: Option<String>,
pub schema_location: Option<String>,
pub type_: Option<String>,
pub category: Option<Vec<ServiceCategoryRef>>,
pub description: Option<String>,
pub is_root: Option<bool>,
pub last_update: Option<DateTime>,
pub lifecycle_status: Option<String>,
pub name: String,
pub parent_id: Option<String>,
pub service_candidate: Option<Vec<ServiceCandidateRef>>,
pub valid_for: Option<TimePeriod>,
pub version: Option<String>,
}Expand description
The (service) category resource is used to group service candidates in logical containers. Categories can contain other categories. Skipped properties: id,href
Fields
base_type: Option<String>When sub-classing, this defines the super-class
schema_location: Option<String>A URI to a JSON-Schema file that defines additional attributes and relationships
type_: Option<String>When sub-classing, this defines the sub-class Extensible name
category: Option<Vec<ServiceCategoryRef>>List of child categories in the tree for in this category
description: Option<String>Description of the category
is_root: Option<bool>If true, this Boolean indicates that the category is a root of categories
last_update: Option<DateTime>Date and time of the last update
lifecycle_status: Option<String>Used to indicate the current lifecycle status
name: StringName of the category
parent_id: Option<String>Unique identifier of the parent category
service_candidate: Option<Vec<ServiceCandidateRef>>List of service candidates associated with this category
valid_for: Option<TimePeriod>A period of time, either as a deadline (endDateTime only) a startDateTime only, or both
version: Option<String>ServiceCategory version