pub struct ServiceCreateEventPayload {
pub service: Option<Service>,
}Expand description
The event data structure
Fields
service: Option<Service>Service is a base class for defining the Service hierarchy. All Services are characterized as either being possibly visible and usable by a Customer or not. This gives rise to the two subclasses of Service: CustomerFacingService and ResourceFacingService.