ServiceTestCreate

Struct ServiceTestCreate 

pub struct ServiceTestCreate {
Show 15 fields pub base_type: Option<String>, pub schema_location: Option<String>, pub type_: Option<String>, pub characteristic: Option<Vec<Characteristic>>, pub description: Option<String>, pub end_date_time: Option<DateTime>, pub mode: Option<String>, pub name: String, pub related_party: Option<Vec<RelatedParty>>, pub related_service: ServiceRef, pub start_date_time: Option<DateTime>, pub state: Option<String>, pub test_measure: Option<Vec<TestMeasure>>, pub test_specification: ServiceTestSpecificationRef, pub valid_for: Option<TimePeriod>,
}
A service test is an entity that exists for a controlled test invocation on a service. The service test is executed according to a schedule and contains service test configuration parameters that are to be applied at execution time, and service test measures that result. Skipped properties: id,href*/

Fields

base_type: Option<String>

When sub-classing, this defines the super-class

schema_location: Option<String>

A URI to a JSON-Schema file that defines additional attributes and relationships

type_: Option<String>

When sub-classing, this defines the sub-class Extensible name

characteristic: Option<Vec<Characteristic>>

List of characteristics with values that define the test run

description: Option<String>

Description of the service test

end_date_time: Option<DateTime>

The end date and time of the service test

mode: Option<String>

An indication of whether the service test is running in “PROACTIVE” or “ONDEMAND” mode

name: String

The name of the service test

related_party: Option<Vec<RelatedParty>>

Party related to the test

related_service: ServiceRef

Service reference, for when Service is used by other entities

start_date_time: Option<DateTime>

The start date and time of the service test.

state: Option<String>

The actual state the service test is in. Recommended states are found in ExecutionStateType schema possible values include acknowledged, rejected, pending, inProgress, cancelled, completed and failed

test_measure: Option<Vec<TestMeasure>>

The results of the test in terms of the measured metrics

test_specification: ServiceTestSpecificationRef

The service test specification used by the service test.

valid_for: Option<TimePeriod>

A period of time, either as a deadline (endDateTime only) a startDateTime only, or both