pub struct ServiceTestDeleteEventPayload {
pub service_test: Option<ServiceTest>,
}Expand description
The event data structure
Fields
service_test: Option<ServiceTest>A service test is an entity that exists for a controlled test invocation on a service. The service test is executed according to a schedule and contains service test configuration parameters that are to be applied at execution time, and service test measures that result.