pub struct CancelServiceOrder {
pub base_type: Option<String>,
pub schema_location: Option<String>,
pub type_: Option<String>,
pub cancellation_reason: Option<String>,
pub completion_message: Option<String>,
pub effective_cancellation_date: Option<DateTime>,
pub error_message: Option<ErrorMessage>,
pub href: Option<String>,
pub id: Option<String>,
pub requested_cancellation_date: Option<DateTime>,
pub service_order: Option<ServiceOrderRef>,
pub state: Option<TaskStateType>,
}Expand description
Request for cancellation an existing Service order
Fields
base_type: Option<String>When sub-classing, this defines the super-class
schema_location: Option<String>A URI to a JSON-Schema file that defines additional attributes and relationships
type_: Option<String>When sub-classing, this defines the sub-class Extensible name
cancellation_reason: Option<String>Reason why the order is cancelled.
completion_message: Option<String>an optional message describing the completion of the task if it is done as expected or it is denied for a reason (like order in an state of PoNR).
effective_cancellation_date: Option<DateTime>Date when the order is cancelled.
error_message: Option<ErrorMessage>represents an Error
href: Option<String>Hyperlink reference
id: Option<String>unique identifier
requested_cancellation_date: Option<DateTime>Date when the submitter wants the order to be cancelled
service_order: Option<ServiceOrderRef>Service Order reference. Useful to understand the which was the Service order through which the service was instantiated in the service inventory
state: Option<TaskStateType>Possible values for the state of a task