pub struct ServiceSpecificationChangeEventPayload {
pub service_specification: Option<ServiceSpecification>,
}Expand description
The event data structure
Fields
service_specification: Option<ServiceSpecification>ServiceSpecification is a class that offers characteristics to describe a type of service. Functionally, it acts as a template by which Services may be instantiated. By sharing the same specification, these services would therefore share the same set of characteristics.