pub struct ServiceTestSpecificationCreate {Show 19 fields
pub base_type: Option<String>,
pub schema_location: Option<String>,
pub type_: Option<String>,
pub attachment: Option<Vec<AttachmentRefOrValue>>,
pub constraint: Option<Vec<ConstraintRef>>,
pub description: Option<String>,
pub entity_spec_relationship: Option<Vec<EntitySpecificationRelationship>>,
pub is_bundle: Option<bool>,
pub last_update: Option<DateTime>,
pub lifecycle_status: Option<String>,
pub name: String,
pub related_party: Option<Vec<RelatedParty>>,
pub related_service_specification: Vec<ServiceSpecificationRef>,
pub service_test_spec_relationship: Option<Vec<ServiceTestSpecRelationship>>,
pub spec_characteristic: Option<Vec<CharacteristicSpecification>>,
pub target_entity_schema: Option<TargetEntitySchema>,
pub test_measure_definition: Option<Vec<TestMeasureDefinition>>,
pub valid_for: Option<TimePeriod>,
pub version: Option<String>,
}Expand description
The service test specification describes the service test in terms of parameters to be configured and measures to be taken. Skipped properties: id,href*/
Fields
base_type: Option<String>When sub-classing, this defines the super-class
schema_location: Option<String>A URI to a JSON-Schema file that defines additional attributes and relationships
type_: Option<String>When sub-classing, this defines the sub-class Extensible name
attachment: Option<Vec<AttachmentRefOrValue>>Attachments that may be of relevance to this specification, such as picture, document, media
constraint: Option<Vec<ConstraintRef>>This is a list of constraint references applied to this specification
description: Option<String>Description of a service test specification.
entity_spec_relationship: Option<Vec<EntitySpecificationRelationship>>Relationship to another specification
is_bundle: Option<bool>isBundle determines whether specification represents a single specification (false), or a bundle of specifications (true).
last_update: Option<DateTime>Date and time of the last update of the specification
lifecycle_status: Option<String>Used to indicate the current lifecycle status of this catalog item
name: StringName given to the specification
Parties who manage or otherwise have an interest in this specification
The related service specification may relate to more than one service specification.
service_test_spec_relationship: Option<Vec<ServiceTestSpecRelationship>>A list of service test specifications related to this specification e.g. dependency, substitution
spec_characteristic: Option<Vec<CharacteristicSpecification>>List of characteristics that the entity can take
target_entity_schema: Option<TargetEntitySchema>The reference object to the schema and type of target entity which is described by a specification
test_measure_definition: Option<Vec<TestMeasureDefinition>>A list of definitions for the measurements for the test defined by this specification
valid_for: Option<TimePeriod>A period of time, either as a deadline (endDateTime only) a startDateTime only, or both
version: Option<String>specification version