pub struct UsageVolumeBalance {
pub base_type: Option<String>,
pub schema_location: Option<String>,
pub type_: Option<String>,
pub href: Option<String>,
pub id: Option<String>,
pub remaining_value: Option<Quantity>,
pub remaining_value_name: Option<String>,
pub valid_for: Option<TimePeriod>,
}Expand description
The balance (called UsageVolumeBalance in the SID model) defines the remaining allowed product usage quantity in terms of volume, time, currency or events. It corresponds to the initial allowed usage quantity minus the usage consumed on the bucket.
Fields
base_type: Option<String>When sub-classing, this defines the super-class
schema_location: Option<String>A URI to a JSON-Schema file that defines additional attributes and relationships
type_: Option<String>When sub-classing, this defines the sub-class Extensible name
href: Option<String>Hyperlink reference
id: Option<String>unique identifier
remaining_value: Option<Quantity>An amount in a given unit
remaining_value_name: Option<String>Remaining value in a formatted string for the bucket given in the balance unit (for example 1.9 Gb). This formatted string could be used for display needs for example
valid_for: Option<TimePeriod>A period of time, either as a deadline (endDateTime only) a startDateTime only, or both